@@ -3,7 +3,7 @@ use std::{borrow::Cow, io};
 use anyhow::bail;
 use gix::bstr::BStr;
 
-use crate::{repository::PathsOrPatterns, OutputFormat};
+use crate::{is_dir_to_mode, repository::PathsOrPatterns, OutputFormat};
 
 pub mod query {
     use std::ffi::OsString;
@@ -44,11 +44,11 @@ pub fn query(
     match input {
         PathsOrPatterns::Paths(paths) => {
             for path in paths {
-                let is_dir = gix::path::from_bstr(Cow::Borrowed(path.as_ref()))
+                let mode = gix::path::from_bstr(Cow::Borrowed(path.as_ref()))
                     .metadata()
                     .ok()
-                    .map(|m| m.is_dir());
-                let entry = cache.at_entry(path.as_slice(), is_dir)?;
+                    .map(|m| is_dir_to_mode(m.is_dir()));
+                let entry = cache.at_entry(path.as_slice(), mode)?;
                 let match_ = entry
                     .matching_exclude_pattern()
                     .and_then(|m| (show_ignore_patterns || !m.pattern.is_negative()).then_some(m));
@@ -66,9 +66,9 @@ pub fn query(
             )?;
 
             if let Some(it) = pathspec.index_entries_with_paths(&index) {
-                for (path, _entry) in it {
+                for (path, entry) in it {
                     pathspec_matched_something = true;
-                    let entry = cache.at_entry(path, Some(false))?;
+                    let entry = cache.at_entry(path, entry.mode.into())?;
                     let match_ = entry
                         .matching_exclude_pattern()
                         .and_then(|m| (show_ignore_patterns || !m.pattern.is_negative()).then_some(m));
@@ -92,10 +92,10 @@ pub fn query(
                     let path = pattern.path();
                     let entry = cache.at_entry(
                         path,
-                        Some(
+                        Some(is_dir_to_mode(
                             workdir.map_or(false, |wd| wd.join(gix::path::from_bstr(path)).is_dir())
                                 || pattern.signature.contains(gix::pathspec::MagicSignature::MUST_BE_DIR),
-                        ),
+                        )),
                     )?;
                     let match_ = entry
                         .matching_exclude_pattern()
