@@ -1,9 +1,10 @@
 fn store() -> crate::Result<crate::file::Store> {
     Ok(crate::file::Store::at(
         gix_testtools::scripted_fixture_read_only_standalone("make_repo_for_reflog.sh")?.join(".git"),
-        gix_ref::store::WriteReflog::Disable,
-        gix_hash::Kind::Sha1,
-        false,
+        gix_ref::store::init::Options {
+            write_reflog: gix_ref::store::WriteReflog::Disable,
+            ..Default::default()
+        },
     ))
 }
 
