@@ -2,7 +2,7 @@ use std::{
     io,
     path::Path,
     slice::Chunks,
-    sync::atomic::{AtomicU64, AtomicUsize, Ordering},
+    sync::atomic::{AtomicUsize, Ordering},
 };
 
 use bstr::BStr;
@@ -19,7 +19,7 @@ use crate::{
         types::{Error, Options},
         Change, Conflict, EntryStatus, Outcome, VisitEntry,
     },
-    SymlinkCheck,
+    is_dir_to_mode, AtomicU64, SymlinkCheck,
 };
 
 /// Calculates the changes that need to be applied to an `index` to match the state of the `worktree` and makes them
@@ -157,11 +157,11 @@ where
             let mut idx = 0;
             while let Some(entry) = chunk_entries.get(idx) {
                 let absolute_entry_index = entry_offset + idx;
-                if idx == 0 && entry.stage() != 0 {
+                if idx == 0 && entry.stage_raw() != 0 {
                     let offset = entry_offset.checked_sub(1).and_then(|prev_idx| {
                         let prev_entry = &all_entries[prev_idx];
                         let entry_path = entry.path_in(state.path_backing);
-                        if prev_entry.stage() == 0 || prev_entry.path_in(state.path_backing) != entry_path {
+                        if prev_entry.stage_raw() == 0 || prev_entry.path_in(state.path_backing) != entry_path {
                             // prev_entry (in previous chunk) does not belong to our conflict
                             return None;
                         }
@@ -276,7 +276,7 @@ impl<'index> State<'_, 'index> {
                 &mut |relative_path, case, is_dir, out| {
                     self.attr_stack
                         .set_case(case)
-                        .at_entry(relative_path, Some(is_dir), objects)
+                        .at_entry(relative_path, Some(is_dir_to_mode(is_dir)), objects)
                         .map_or(false, |platform| platform.matching_attributes(out))
                 },
             )
@@ -286,7 +286,7 @@ impl<'index> State<'_, 'index> {
             self.skipped_by_pathspec.fetch_add(1, Ordering::Relaxed);
             return None;
         }
-        let status = if entry.stage() != 0 {
+        let status = if entry.stage_raw() != 0 {
             Ok(
                 Conflict::try_from_entry(entries, self.path_backing, entry_index, path).map(|(conflict, offset)| {
                     *outer_entry_index += offset; // let out loop skip over entries related to the conflict
@@ -424,12 +424,19 @@ impl<'index> State<'_, 'index> {
 
         self.buf.clear();
         self.buf2.clear();
+        let file_size_bytes = if cfg!(windows) && metadata.is_symlink() {
+            // symlinks on Windows seem to have a length of zero, so just pretend
+            // they have the correct length to avoid short-cutting, and enforce a full buffer check.
+            entry.stat.size as u64
+        } else {
+            metadata.len()
+        };
         let fetch_data = ReadDataImpl {
             buf: &mut self.buf,
             path: worktree_path,
             rela_path,
             entry,
-            file_len: metadata.len(),
+            file_len: file_size_bytes,
             filter: &mut self.filter,
             attr_stack: &mut self.attr_stack,
             options: self.options,
@@ -440,7 +447,7 @@ impl<'index> State<'_, 'index> {
             odb_reads: self.odb_reads,
             odb_bytes: self.odb_bytes,
         };
-        let content_change = diff.compare_blobs(entry, metadata.len(), fetch_data, &mut self.buf2)?;
+        let content_change = diff.compare_blobs(entry, file_size_bytes, fetch_data, &mut self.buf2)?;
         // This file is racy clean! Set the size to 0 so we keep detecting this as the file is updated.
         if content_change.is_some() || executable_bit_changed {
             let set_entry_stat_size_zero = content_change.is_some() && racy_clean;
@@ -531,7 +538,8 @@ where
         let out = if is_symlink && self.options.fs.symlink {
             // conversion to bstr can never fail because symlinks are only used
             // on unix (by git) so no reason to use the try version here
-            let symlink_path = gix_path::into_bstr(std::fs::read_link(self.path)?);
+            let symlink_path =
+                gix_path::to_unix_separators_on_windows(gix_path::into_bstr(std::fs::read_link(self.path)?));
             self.buf.extend_from_slice(&symlink_path);
             self.worktree_bytes.fetch_add(self.buf.len() as u64, Ordering::Relaxed);
             Stream {
@@ -541,7 +549,9 @@ where
             }
         } else {
             self.buf.clear();
-            let platform = self.attr_stack.at_entry(self.rela_path, Some(false), &self.objects)?;
+            let platform = self
+                .attr_stack
+                .at_entry(self.rela_path, Some(self.entry.mode), &self.objects)?;
             let file = std::fs::File::open(self.path)?;
             let out = self
                 .filter
@@ -604,7 +614,7 @@ impl Conflict {
         let mut count = 0_usize;
         for stage in (start_index..(start_index + 3).min(entries.len())).filter_map(|idx| {
             let entry = &entries[idx];
-            let stage = entry.stage();
+            let stage = entry.stage_raw();
             (stage > 0 && entry.path_in(path_backing) == entry_path).then_some(stage)
         }) {
             // This could be `1 << (stage - 1)` but let's be specific.
