@@ -7,9 +7,9 @@ use std::{
     },
 };
 
+use crate::shared::pretty::prepare_and_run;
 use anyhow::{anyhow, Context, Result};
 use clap::{CommandFactory, Parser};
-use gitoxide::shared::pretty::prepare_and_run;
 use gitoxide_core as core;
 use gitoxide_core::{pack::verify, repository::PathsOrPatterns};
 use gix::bstr::{io::BufReadExt, BString};
@@ -24,7 +24,7 @@ use crate::plumbing::{
 
 #[cfg(feature = "gitoxide-core-async-client")]
 pub mod async_util {
-    use gitoxide::shared::ProgressRange;
+    use crate::shared::ProgressRange;
 
     #[cfg(not(feature = "prodash-render-line"))]
     compile_error!("BUG: Need at least a line renderer in async mode");
@@ -38,7 +38,7 @@ pub mod async_util {
         Option<prodash::render::line::JoinHandle>,
         gix_features::progress::DoOrDiscard<prodash::tree::Item>,
     ) {
-        use gitoxide::shared::{self, STANDARD_RANGE};
+        use crate::shared::{self, STANDARD_RANGE};
         shared::init_env_logger();
 
         if verbose {
@@ -404,6 +404,7 @@ pub fn main() -> Result<()> {
             handshake_info,
             bare,
             no_tags,
+            ref_name,
             remote,
             shallow,
             directory,
@@ -413,6 +414,7 @@ pub fn main() -> Result<()> {
                 bare,
                 handshake_info,
                 no_tags,
+                ref_name,
                 shallow: shallow.into(),
             };
             prepare_and_run(
@@ -732,7 +734,7 @@ pub fn main() -> Result<()> {
                         &url,
                         directory,
                         refs_directory,
-                        refs.into_iter().map(|s| s.into()).collect(),
+                        refs.into_iter().map(Into::into).collect(),
                         progress,
                         core::pack::receive::Context {
                             thread_limit,
@@ -1214,6 +1216,17 @@ pub fn main() -> Result<()> {
                     core::repository::mailmap::entries(repository(Mode::Lenient)?, format, out, err)
                 },
             ),
+            mailmap::Subcommands::Check { contacts } => prepare_and_run(
+                "mailmap-check",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, err| {
+                    core::repository::mailmap::check(repository(Mode::Lenient)?, format, contacts, out, err)
+                },
+            ),
         },
         Subcommands::Attributes(cmd) => match cmd {
             attributes::Subcommands::Query { statistics, pathspec } => prepare_and_run(
