@@ -126,7 +126,7 @@ pub mod tools {
 
     #[cfg(feature = "gitoxide-core-tools-query")]
     pub mod query {
-        use gitoxide::shared::AsPathSpec;
+        use crate::shared::AsPathSpec;
 
         #[derive(Debug, clap::Subcommand)]
         pub enum Command {
@@ -153,7 +153,7 @@ pub mod tools {
         #[clap(default_value = ".")]
         pub working_dir: PathBuf,
         /// The name of the revision as spec, like 'HEAD' or 'main' at which to start iterating the commit graph.
-        #[clap(default_value("HEAD"), value_parser = gitoxide::shared::AsBString)]
+        #[clap(default_value("HEAD"), value_parser = crate::shared::AsBString)]
         pub rev_spec: BString,
         /// Ignore github bots which match the `[bot]` search string.
         #[clap(short = 'b', long)]
